@@ -4,7 +4,7 @@ from django.db import transaction
 from django.contrib import messages
 from django.shortcuts import render, redirect
 from django.contrib import admin
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class UpdatePricesForm(forms.Form):
