@@ -1,6 +1,6 @@
 
 from django.db import models
-from django.utils.translation import ugettext, ugettext_lazy as _
+from django.utils.translation import gettext, gettext_lazy as _
 
 from solo.models import SingletonModel
 
@@ -25,7 +25,7 @@ class ExchangeRates(SingletonModel):
     usd_eur = models.FloatField(_('USD - EUR'), default=1)
 
     def __str__(self):
-        return ugettext('Exchange rates')
+        return gettext('Exchange rates')
 
     class Meta:
         verbose_name = _('Exchange rates')
