@@ -1,7 +1,6 @@
 
-from django.shortcuts import redirect
+from django.shortcuts import redirect, HttpResponse
 from django.views.decorators.http import require_POST
-from django.http.response import JsonResponse
 
 from exchange.constants import CURRENCY_SESSION_KEY
 from exchange.forms import CurrencyForm
@@ -13,7 +12,7 @@ def set_currency(request):
     form = CurrencyForm(request.POST)
 
     if not form.is_valid():
-        return JsonResponse(form.errors.as_json())
+        return HttpResponse(str(form.errors))
 
     currency = form.cleaned_data['currency']
 
